library(testthat)
library(nat.nblast)

test_check("nat.nblast")
